@@ -21,8 +21,10 @@
 #include <opencv2/imgproc.hpp>
 #include <opencv2/imgcodecs/legacy/constants_c.h>
 #include "opencv2/core/types_c.h"
+#include <opencv2/opencv.hpp>
 #include "libmaix_cv_image.h"
 #include "libmaix_disp.h"
+
 // #include "NanoLog.hpp"
 #define enable_PIL
 #define enable_numpy
@@ -98,6 +100,7 @@ public:
   py::list _imlib_find_apriltags(std::vector<int> &roi, int families, float fx, float fy, float cx, float cy);
   py::list _imlib_find_qrcodes(std::vector<int> &roi);
   py::list _imlib_find_barcodes(std::vector<int> &roi);
+  py::list _imlib_find_blobs(std::vector<std::vector<int>> &thresholds_src, std::vector<int> roi_src, int x_stride, int y_stride, bool invert, int area_threshold, int pixels_threshold, bool merge, int margin, int x_hist_bins_max, int y_hist_bins_max);
 };
 
 class maix_image : virtual public any_image, public maix_vision, public maix_custom
@@ -192,6 +195,8 @@ public:
 
   py::list _imlib_get_statistics(std::vector<int> roi_src, std::vector<std::vector<int>> &thresholds_src, bool invert, maix_image & other_src, int bins, int l_bins, int a_bins, int b_bins);
 
+  py::dict _imlib_find_template(maix_image &template_src, float arg_thresh, std::vector<int> roi_src, int step, int search);
+
   // void imlib_rotation_corr(image_t *img, float x_rotation, float y_rotation,
   //                  float z_rotation, float x_translation, float y_translation,
   //                  float zoom, float fov, float *corners);
